@@ -20,6 +20,7 @@
 #               2024/11/26 - PH Also write GPSMeasureMode and GPSDOP
 #               2024/11/05 - PH Added support for Google Maps "Export timeline data"
 #                               JSON format
+#               2025/09/22 - PH Added ability to read Columbus CSV  log files
 #
 # References:   1) http://www.topografix.com/GPX/1/1/
 #               2) http://www.gpsinformation.org/dale/nmea.htm#GSA
@@ -34,7 +35,7 @@ use vars qw($VERSION);
 use Image::ExifTool qw(:Public);
 use Image::ExifTool::GPS;
 
-$VERSION = '1.81';
+$VERSION = '1.83';
 
 sub JITTER() { return 2 }       # maximum time jitter
 
@@ -275,6 +276,7 @@ sub LoadTrackLog($$;$)
             } elsif (((/\b(GPS)?Date/i and /\b(GPS)?(Date)?Time/i) or /\bTime\(seconds\)/i) and /\Q$csvDelim/) {
                 chomp;
                 @csvHeadings = split /\Q$csvDelim/;
+                my $isColumbus = ($csvHeadings[0] and $csvHeadings[0] eq 'INDEX'); # (Columbus GPS logger)
                 $format = 'CSV';
                 # convert recognized headings to our parameter names
                 foreach (@csvHeadings) {
@@ -306,7 +308,7 @@ sub LoadTrackLog($$;$)
                     } elsif (/^(Pos)?Lon/i) {
                         $param = 'lon';
                         /ref$/i and $param .= 'ref';
-                    } elsif (/^(Pos)?Alt/i) {
+                    } elsif (/^(Pos)?(Alt|Height)/i) {
                         $param = 'alt';
                     } elsif (/^Speed/i) {
                         $param = 'speed';
@@ -314,6 +316,9 @@ sub LoadTrackLog($$;$)
                         if (m{\((mph|km/h|m/s)\)}) {
                             $scaleSpeed = $otherConv{$1};
                             $xtra = " in $1";
+                        } elsif ($isColumbus) { # (Columbus GPS logger)
+                            $scaleSpeed = $otherConv{'km/h'};
+                            $xtra = " in km/h";
                         } else {
                             $xtra = ' in knots';
                         }
@@ -541,12 +546,16 @@ DoneFix:    $isDate = 1;
                         $date = Time::Local::timegm(0,0,0,$1,$2-1,$3);
                     } elsif ($val =~ /(\d{4}).*?(\d{2}).*?(\d{2})/) {
                         $date = Time::Local::timegm(0,0,0,$3,$2-1,$1);
+                    } elsif ($val =~ /^(\d{2})(\d{2})(\d{2})$/) { # (Columbus GPS logger)
+                        $date = Time::Local::timegm(0,0,0,$3,$2-1,$1+2000);
                     }
                 } elsif ($param eq 'time') {
                     if ($val =~ /^(\d{1,2}):(\d{2}):(\d{2}(\.\d+)?).*?(([-+])(\d{1,2}):?(\d{2}))?/) {
                         $secs = (($1 * 60) + $2) * 60 + $3;
                         # adjust for time zone if specified
                         $secs += ($7 * 60 + $8) * ($6 eq '-' ? 60 : -60) if $5;
+                    } elsif ($val =~ /^(\d{2})(\d{2})(\d{2})$/) { # (Columbus GPS logger)
+                        $secs = (($1 * 60) + $2) * 60 + $3;
                     }
                 } elsif ($param eq 'lat' or $param eq 'lon') {
                     $$fix{$param} = Image::ExifTool::GPS::ToDegrees($val, 1);
@@ -1336,6 +1345,23 @@ Category:       foreach $category (qw{pos track alt orient atemp err dop}) {
             if (defined $dop) {
                 $et->SetNewValue(GPSMeasureMode => $mm, %opts);
                 $et->SetNewValue(GPSDOP => $dop, %opts);
+                # also set GPSHPositioningError if specified
+                my $hposErr = $$et{OPTIONS}{GeoHPosErr};
+                if ($hposErr) {
+                    $hposErr =~ s/gpsdop/GPSDOP/i;
+                    my $GPSDOP = $dop;
+                    local $SIG{'__WARN__'} = \&Image::ExifTool::SetWarning;
+                    undef $Image::ExifTool::evalWarning;
+                    #### eval GeoHPosErr ($GPSDOP)
+                    $hposErr = eval $hposErr;
+                    my $err = Image::ExifTool::GetWarning() || $@;
+                    if ($err) {
+                        $err = Image::ExifTool::CleanWarning($err);
+                        $et->Warn("Error calculating GPSHPositioningError: $err", 1);
+                    } else {
+                        $et->SetNewValue(GPSHPositioningError => $hposErr, %opts);
+                    }
+                }
             }
         }
         unless ($xmp) {
@@ -1549,7 +1575,8 @@ This module loads GPS track logs, interpolates to determine position based
 on time, and sets new GPS values for geotagging images.  Currently supported
 formats are GPX, NMEA RMC/GGA/GLL/GSA/ZDA, KML, IGC, Garmin XML and TCX,
 Magellan PMGNTRK, Honeywell PTNTHPR, Bramor gEO, Winplus Beacon text,
-GPS/IMU CSV, DJI CSV, ExifTool CSV and 3 different Google JSON formats.
+GPS/IMU CSV, DJI/Columbus/ExifTool CSV format and 3 different Google JSON
+formats.
 
 Methods in this module should not be called directly.  Instead, the Geotag
 feature is accessed by writing the values of the ExifTool Geotag, Geosync
